"""
This segmenter is potentially useful for small docs that should be treated as a single sentence. May work better
for tweets than default segmentation based on parsing.
"""

class TrivialSegmenter(object):
    def __init__(self):
        pass

    def set_sent_starts(self, doc):
        doc[0].is_sent_start = True

        for t in doc[1:]:
            t.is_sent_start = False

        return doc


if __name__ == "__main__":
    samples = """
    summ tweet stufff https://t.co/fjSFjfj9k @Som1 @somOneElse this @isaSentence... sorta kinda not really ;-)
    """

    import spacy

    nlp = spacy.load('en')
    nlp.add_pipe(TrivialSegmenter().set_sent_starts, name='sentence_segmenter', before='parser')
    doc = nlp(samples)



"""
This segmenter's template was based on reading the following github issue:
https://github.com/explosion/spaCy/pull/1400
"""

import re

class NewLineSegmenter(object):
    def __init__(self):
        pass

    def is_nl_token(self, t):

        # if a token consists of all space, and has at least one newline char, we segment as a sentence.
        if t.is_space and '\n' in t.text:
            return True
        else:
            return False

    def set_sent_starts(self, doc):
        if self.is_nl_token(doc[0]):
            doc[0].is_sent_start = True
        else:
            doc[0].is_sent_start = False
        if len(doc) == 1:
            return doc

        for t in doc[1:]:
            if self.is_nl_token(doc[t.i - 1]) and not self.is_nl_token(t):
                t.is_sent_start = True
            else:
                t.is_sent_start = False

        return doc


if __name__ == "__main__":
    samples = """

         this is my first sentence
    this is my second one    
    third one!

             definitely



    difrent sents in
    these lines heree

    """

    import spacy

    nlp = spacy.load('en')
    nlp.add_pipe(NewLineSegmenter().set_sent_starts, name='sentence_segmenter', before='parser')
    doc = nlp(samples)



from distutils.core import setup

setup(
    name='spacyss',
    version='1.0.1',
    packages=['seg', 'seg.newline', 'seg.singsent'],
    url='https://github.com/tc64/spacyss',
    license='',
    author='Taylor Cassidy',
    author_email='taylorcassidy64@gmail.com',
    description='sentence segmenters for spacy2.0+'
)

# Nothing to set up at the moment!
